%INERTIAPOIS
% For debugging; only upwind, uniform grid, Poiseuille
% Contributions of inertia terms 
% Output: cu1, cv1

% Indexing convention in staggered grid:
%  +--k+1--+ 
%  |       |
%  j  jk  j+1
%  |       |
%  +---k---+ 
if n < 2, tic, end

cu1 = zeros(size(XU)); cv1 = zeros(size(XV));

up = reshape(u0,size(XU')); up = up';		% Two-index reordering of u0
vp = reshape(v0,size(XV')); vp = vp';		%  and v0

%up = zeros(size(XU)); vp = YV;

% Velocity field in cell vertices:
uav = [up;up(K,:)];			% uav: average u in cell vertices	
uav(2:K,:) = (uav(1:K-1,:) + uav(2:K,:))/2;
vav = [vp,vp(:,J)];			% vav: average v in cell vertices  
vav(:,2:J) = (vav(:,1:J-1) + vav(:,2:J))/2;
% Boundary corrections
uav(1,:) = ulower(:)'; uav(K+1,:) = uupper(:)';
vav(:,1) = vleft(:);
  
  uu = up; up = ((uu + abs(uu))/2).^2; um = ((uu - abs(uu))/2).^2; 
  vv = vp; vp = ((vv + abs(vv))/2).^2; vm = ((vv - abs(vv))/2).^2;   
  vpv = (vav + abs(vav))/2; vmv = (vav - abs(vav))/2;
  upv = (uav + abs(uav))/2; umv = (uav - abs(uav))/2;
  
  cu1(:,2:J) = up(:,2:J) + um(:,3:J+1) - up(:,1:J-1) - um(:,2:J);
  cu1(:,1) = um(:,2) + up(:,1) - uu(:,1).^2;  
  cu1(:,J+1) = uu(:,J+1).^2 - up(:,J) - um(:,J+1);
  
  uv = zeros(size(vpv)); 
  uv(2:K,:) = vpv(2:K,:).*uu(1:K-1,:) + vmv(2:K,:).*uu(2:K,:);
  uv(1,:) = vpv(1,:).*uav(1,:) + vmv(1,:).*uu(1,:);
  uv(K+1,:) = vpv(K+1,:).*uu(K,:) + vmv(K+1,:).*uav(K+1,:);
  cu1 = cu1./DXU + (uv(2:K+1,:) - uv(1:K,:))./DYU;
  
  cv1(2:K,:) = vp(2:K,:) + vm(3:K+1,:) - vp(1:K-1,:) - vm(2:K,:);
  cv1(1,:) = vp(1,:) + vm(2,:) - vv(1,:).^2;
  cv1(K+1,:) = vv(K+1,:).^2 - vm(K+1,:) - vp(K,:); 
  uv(:,2:J) = upv(:,2:J).*vv(:,1:J-1) + umv(:,2:J).*vv(:,2:J);
  uv(:,1) = upv(:,1).*vav(:,1) + umv(:,1).*vv(:,1);
  uv(:,J+1) = upv(:,J+1).*vv(:,J) + umv(:,J+1).*vav(:,J+1);
  cv1 = cv1./DYV + (uv(:,2:J+1) - uv(:,1:J))./DXV;

% Boundary conditions: no-slip or inflow
cu1(:,1) = 0; cv1(1,:) = 0; cv1(K+1,:) =0;

cu1 = cu1'; cu1 = cu1(:); cv1 = cv1'; cv1 = cv1(:);
if n<2, tijd = toc; disp(['inertiapois time = ',num2str(tijd)]), end

%cu0 = cu1; cv0 = cv1;
