function ye = tau(Re, umax, vmax, hx, hy, central)
%TAU  Computes stability condition for Adams-Bashforth-Crank-Nicolson scheme	

ye = 0;
if central == 1		% Central scheme for inertia terms
  tau1 = (4/3)/(Re*(umax^2 + vmax^2));
  tau2 = Re/(4*(1/hx^2 + 1/hy^2));
  tau3 = (3/Re)^(1/3)/((umax^2/hx)^(2/3) + (vmax^2/hy)^(2/3));
else			% Upwind scheme for inertia terms
  tau1 = (2/(3*Re))/(umax^2/(2+umax*hx*Re) + vmax^2/(2+vmax*hy*Re));
  tau2 = Re/(4*((1+umax*hx*Re/2)/hx^2 + (1+vmax*hy*Re/2)/hy^2));
  tau3 = (3/Re)^(1/3)/((umax^4/(hx^2 + umax*hx^3*Re/2))^(1/3) +...
  	(vmax^4/(hy^2 + vmax*hy^3*Re/2))^(1/3));
end
ye = max([tau1, min([tau2,tau3])]);
disp(['tau1 = ',num2str(tau1),' tau2 = ',num2str(tau2),...
  ' tau3 = ',num2str(tau3)]) 
