%PO
% Numerical solution of 2D and 3D Poisson equation on uniform square grid

% Copyright 2001 P. Wesseling
% This program and its subprograms may be freely used, modified and distributed
% under the GNU General Public License: http://www.gnu.org/copyleft/gpl.html

% Theory is given in Chapter 6 of
%	Elements of Computational Fluid Dynamics
%	Lecture Notes by P. Wesseling
%	Department of Applied Mathematical Analysis, ITS, TU Delft
% See http://ta.twi.tudelft.nl/nw/users/wesseling/

% This program generates Figures  and  in the Lecture Notes.

% Functions called: my_cholinc

clear all

% ........................................Input..............................
dim = 2;	% Number of dimensions = 2 or 3
n = 50;		% n^dim grid 
% ....................................End of input...........................
if dim ~= 2 & dim ~= 3, error('Wrong value of dim'), end

disp(['Number of unknowns x = ',num2str(n^dim)])

e = ones(n,1); B = spdiags([-e 2*e -e],[-1 0 1],n,n); I = eye(n);
if dim == 2
  A = kron(I,B) + kron(B,I);	% 5-point Laplace finite difference matrix 
  b = ones(n^2,1)/(n+1)^2;	% Right-hand side for Poisson equation
else
	% 7-point 3D Laplace finite difference matrix: 
  A = kron(I,kron(I,B)) + kron(I,kron(B,I)) + kron(B,kron(I,I));
  b = ones(n^3,1)/(n+1)^2;	% Right-hand side for Poisson equation
end

	% Sparse direct method
flops(0), tic, ye = A\b; tijd = toc; 
disp(['Direct solution time z = ',num2str(tijd)])
disp(['Direct solution Mflops = ',num2str(flops/1.e6)])

	% First order incomplete Cholesky decomposition
%flops(0), tic
%U = cholinc(A,'0'); L = U'; tijd = toc;	% MATLAB version	
%disp(['cholinc time = ',num2str(tijd)])
%disp(['cholinc Mflops = ',num2str(flops/1.e6)])

flops(0), tic
my_cholinc	      % My implementation of incomplete Cholesky decomposition
tijd = toc; 
disp(['my_cholinc time = ',num2str(tijd)])
disp(['my_cholinc Mflops = ',num2str(flops/1.e6)])

rand('state',2)		% Fixing the state of the random number generator 
flops(0), tic
	% Preconditioned CG method with random initial guess:
ycg = pcg(A,b,1e-2,200,L,L',rand(size(b)));	

	% Preconditioned CG method with zero initial guess:
%ycg = pcg(A,b,1e-2,200,L,L');	

tijd = toc; 
disp(['ICCG time y = ',num2str(tijd)])
disp(['ICCG Mflops = ',num2str(flops/1.e6)])

	% Unpreconditioned CG method with random initial guess:
%rand('state',2)	% Fixing the state of the random number generator
%tic, yy = pcg(A,b,1e-2,200,[],[],rand(size(b))); tijd = toc; 
%disp(['Unpreconditioned CG time = ',num2str(tijd)])

disp(['Maximum error = ',num2str(norm(ye-ycg,inf))])

%if dim == 2
%  ye = reshape(ye,n,n); surf(ye')	% Make surface plot
%end

